<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ext="java:lu.bourse.api.deposant.action.xsl.XslManager"
	xmlns:ns="http://www.bourse.lu/rap/O11"
	xmlns:fnbourse="http://www.bcl.lu/2006/bcl-xpath-functions"
	exclude-result-prefixes="ext fnbourse"
	version="2.0">

	<xsl:output method="xml" indent="yes" />
	
	<xsl:param name="spaceParam" />
	
	<!--  -->
	<!-- Début Partie sur les Tests de Contrôles liées aux fichiers Déposés -->
	<!--  -->
	<xsl:template name="obtenirDateFormatee">
		<xsl:param name="dateEntree" />
		<xsl:param name="formatEntree" />
		<xsl:param name="formatSortie" />
		<xsl:variable name="timeVide" select="'00:00:00'" />

		<xsl:choose>
			<xsl:when test="$formatEntree='ddmmyyyy'">
				<xsl:choose>
					<xsl:when test="$formatSortie='date'">
						<xsl:value-of
							select="concat(substring($dateEntree, 5, 4), '-', substring($dateEntree, 3, 2), '-', substring($dateEntree, 1, 2))" />
					</xsl:when>
					<xsl:when test="$formatSortie='dateTime'">
						<xsl:value-of
							select="concat(substring($dateEntree, 5, 4), '-', substring($dateEntree, 3, 2), '-', substring($dateEntree, 1, 2), 'T', $timeVide, 'Z')" />
					</xsl:when>
				</xsl:choose>
			</xsl:when>

			<xsl:when test="$formatEntree='yyyymmdd_hhmmss'">
				<xsl:choose>
					<xsl:when test="$formatSortie='date'">
						<xsl:value-of
							select="concat(substring($dateEntree, 1, 4), '-', substring($dateEntree, 5, 2), '-', substring($dateEntree, 7, 2))" />
					</xsl:when>
					<xsl:when test="$formatSortie='dateTime'">
						<xsl:value-of
							select="concat(substring($dateEntree, 1, 4), '-', substring($dateEntree, 5, 2), '-', substring($dateEntree, 7, 2), 'T', substring($dateEntree, 10, 2), ':', substring($dateEntree, 12, 2), ':', substring($dateEntree, 14, 2), 'Z')" />
					</xsl:when>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="boucleTest" match="/file">

		<xsl:param name="iteration" select="1" />


		<xsl:if test="count(row) > $iteration ">
			<xsl:call-template name="boucleTest">
				<xsl:with-param name="iteration"
					select="$iteration + 1" />
			</xsl:call-template>
		</xsl:if>

		<!--  -->
		<!-- Fin Partie sur les Tests de Contrôles liés aux fichiers Déposés -->
		<!--  -->

		<!--  -->
		<!--  On n'effectue la transformation em Message Pivot seulement si l'ensemble des Tests ont été réalisés avec succès -->
		<!--  -->
		<xsl:if test="$iteration = count(row)">
			<ns:MsgInO11>
				<ns:Vers SchemaVers="1.0">
					<xsl:variable name="numVersXSD"
						select="ext:recupNumVersXSDFile($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:value-of select="$numVersXSD" />
				</ns:Vers>
				<xsl:call-template name="ELT-TECH" />
				<ns:SeqInO11>
					<ns:Conc1>
						<xsl:call-template name="SEQUENCE-IN-O11" />
					</ns:Conc1>
				</ns:SeqInO11>
			</ns:MsgInO11>
		</xsl:if>

	</xsl:template>
	
	<xsl:template name="replace-string">
	  <xsl:param name="str" />
		<xsl:param name="strToReplace" />
		<xsl:param name="newStr" />
		<xsl:choose>
  		<xsl:when test="contains($str,$strToReplace)">
        <xsl:value-of select="concat(substring-before($str,$strToReplace),$newStr)"/>
        <xsl:call-template name="replace-string"> 
          <xsl:with-param name="str" select="substring-after($str,$strToReplace)" /> 
          <xsl:with-param name="strToReplace" select="$strToReplace" /> 
          <xsl:with-param name="newStr" select="$newStr" /> 
        </xsl:call-template> 
      </xsl:when> 
      <xsl:otherwise>
        <xsl:value-of select="$str"/>
      </xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="ELT-TECH">
		<ns:other>
			<ns:EltTech>
				<ns:ListeDev>
					<xsl:value-of select="ext:getListeDevises()" />
				</ns:ListeDev>
				<ns:CdLang>
					<xsl:value-of select="ext:getLang()" />
				</ns:CdLang>
				<ns:UrlCombo>
					<xsl:value-of select="ext:recupDonnee('WS_URL_COMBO', $spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				</ns:UrlCombo>
				<ns:UrlDownload>
					<xsl:value-of select="ext:recupDonnee('WS_URL_DOWNLOAD', $spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				</ns:UrlDownload>
				<ns:UrlCmun>
					<xsl:value-of select="ext:recupDonnee('WS_URL_COMMUN', $spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				</ns:UrlCmun>
				<ns:CdIdentAcCssf>
					<xsl:value-of select="ext:obtenirCdAcCssf($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				</ns:CdIdentAcCssf>
				<ns:CdIdentAcBcl>
					<xsl:value-of select="ext:obtenirCdAc($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				</ns:CdIdentAcBcl>				
				<ns:DtCre>
					<xsl:variable name="dateDuJour"
						select="ext:recupDateDuJour($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:call-template name="obtenirDateFormatee">
						<xsl:with-param name="dateEntree"
							select="$dateDuJour" />
						<xsl:with-param name="formatEntree"
							select="'yyyymmdd_hhmmss'" />
						<xsl:with-param name="formatSortie"
							select="'dateTime'" />
					</xsl:call-template>
				</ns:DtCre>
				<ns:DtEnvoi>
					<xsl:variable name="dateDuJour"
						select="ext:recupDateDuJour($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:call-template name="obtenirDateFormatee">
						<xsl:with-param name="dateEntree"
							select="$dateDuJour" />
						<xsl:with-param name="formatEntree"
							select="'yyyymmdd_hhmmss'" />
						<xsl:with-param name="formatSortie"
							select="'dateTime'" />
					</xsl:call-template>
				</ns:DtEnvoi>
				<ns:DtValidat>
					<xsl:variable name="dateDuJour"
						select="ext:recupDateDuJour($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:call-template name="obtenirDateFormatee">
						<xsl:with-param name="dateEntree"
							select="$dateDuJour" />
						<xsl:with-param name="formatEntree"
							select="'yyyymmdd_hhmmss'" />
						<xsl:with-param name="formatSortie"
							select="'dateTime'" />
					</xsl:call-template>
				</ns:DtValidat>
				<ns:NumMess>
					<xsl:variable name="numMess"
						select="ext:recupNumeroMessage($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:value-of select="$numMess" />
				</ns:NumMess>
				<ns:MotPasAc>
					<xsl:variable name="pwdAc"
						select="ext:obtenirPwdAc($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:value-of select="$pwdAc" />
				</ns:MotPasAc>
				<ns:CdAuthent>
					<xsl:variable name="cdAuth"
						select="ext:obtenirCodeAuth($spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:value-of select="$cdAuth" />
				</ns:CdAuthent>
				<ns:CdOpe>
					<xsl:value-of
						select="row[@id='filtre1401']/col[@id=3]" />
				</ns:CdOpe>
				<ns:Sess>
					<xsl:value-of select="''" />
				</ns:Sess>
				<ns:IdTypeDoc>
					<xsl:variable name="typeDoc"
						select="ext:recupDonnee('TYPE_DOC', $spaceParam)"
						xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
					<xsl:value-of select="$typeDoc" />
				</ns:IdTypeDoc>
			</ns:EltTech>
		</ns:other>

	</xsl:template>

	<xsl:template name="SEQUENCE-IN-O11">

		<xsl:call-template name="SEGMENT-CONTEXT" />
		<xsl:call-template name="SEGMENT-ACTIF" />
		<xsl:call-template name="SEGMENT-PORTF" />
		<xsl:call-template name="SEGMENT-MT" />
		<xsl:call-template name="SEGMENT-REV" />
		<xsl:call-template name="SEGMENT-DISTRIB" />

	</xsl:template>

	<xsl:template name="SEGMENT-CONTEXT">
		<ns:Context>
			<xsl:call-template name="CONTEXT-STRUCT-JUR-OPC" />
			<xsl:call-template name="CONTEXT-TECH" />
			<xsl:call-template name="CONTEXT-TECHCONTACT" />
			<xsl:call-template name="CONTEXT-INSTRCOMPART" />
			<xsl:call-template name="CONTEXT-INSTRFONDS" />
			<xsl:call-template name="CONTEXT-DEV" />
			<xsl:call-template name="CONTEXT-COLLCOMPARTRAPO11" />
		</ns:Context>
	</xsl:template>

	<xsl:template name="CONTEXT-STRUCT-JUR-OPC">
		<ns:StructJurOpc>
			<ns:CdStructJurOpc>
				<xsl:variable name="idStructJurOpc"
					select="ext:recupDonnee('IDSTRUCTJUROPC', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$idStructJurOpc" />
			</ns:CdStructJurOpc>
		</ns:StructJurOpc>
	</xsl:template>

	<xsl:template name="CONTEXT-TECH">
		<ns:Tech>
			<ns:Adr>
				<xsl:variable name="adresse1"
					select="ext:recupDonnee('ADDRESSE1', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$adresse1" />
				<xsl:variable name="adresse2"
					select="ext:recupDonnee('ADDRESSE2', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$adresse2" />
			</ns:Adr>
			<ns:CdPostal>
				<xsl:variable name="cdpostal"
					select="ext:recupDonnee('CDPOSTAL', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$cdpostal" />
			</ns:CdPostal>
			<ns:Ville>
				<xsl:variable name="ville"
					select="ext:recupDonnee('VILLE', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$ville" />
			</ns:Ville>
			<ns:Pays>
				<xsl:variable name="pays"
					select="ext:recupDonnee('IDPAYS', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$pays" />
			</ns:Pays>
		</ns:Tech>
	</xsl:template>

	<xsl:template name="CONTEXT-TECHCONTACT">
		<ns:TechContact>
			<ns:Titre>
				<xsl:value-of select="''" />
			</ns:Titre>
			<ns:Nom>
				<xsl:variable name="nomUtil"
					select="ext:recupDonnee('NOMUTIL', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$nomUtil" />
			</ns:Nom>
			<ns:Prenom>
				<xsl:variable name="prenomUtil"
					select="ext:recupDonnee('PRENOMUTIL', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$prenomUtil" />
			</ns:Prenom>
			<ns:Tel>
				<xsl:variable name="tel"
					select="ext:recupDonnee('TEL', $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:value-of select="$tel" />
			</ns:Tel>
		</ns:TechContact>
	</xsl:template>

	<xsl:template name="CONTEXT-COLLCOMPARTRAPO11">
		<ns:CollCompartRapO11>
			<ns:CdCssfOpc>
				<xsl:value-of
					select="normalize-space(row[@id='filtre1401']/col[@id=4])" />
			</ns:CdCssfOpc>
			<ns:CdCssfCompart>
				<xsl:value-of
					select="normalize-space(row[@id='filtre1401']/col[@id=5])" />
			</ns:CdCssfCompart>
			<ns:CdAacOpc>
				<xsl:value-of select="row[@id='filtre1401']/col[@id=6]" />
			</ns:CdAacOpc>
			<ns:CdAacCompart>
				<xsl:value-of select="row[@id='filtre1401']/col[@id=7]" />
			</ns:CdAacCompart>
			<ns:DtDebRap>
				<xsl:variable name="dtDebRap"
					select="row[@id='filtre1401']/col[@id=8]" />
				<xsl:call-template name="obtenirDateFormatee">
					<xsl:with-param name="dateEntree"
						select="ext:obtenirDate($dtDebRap)" />
					<xsl:with-param name="formatEntree"
						select="'ddmmyyyy'" />
					<xsl:with-param name="formatSortie" select="'date'" />
				</xsl:call-template>
			</ns:DtDebRap>
			<ns:DtFinRap>
				<xsl:variable name="dtFinRap"
					select="row[@id='filtre1401']/col[@id=9]" />
				<xsl:call-template name="obtenirDateFormatee">
					<xsl:with-param name="dateEntree"
						select="ext:obtenirDate($dtFinRap)" />
					<xsl:with-param name="formatEntree"
						select="'ddmmyyyy'" />
					<xsl:with-param name="formatSortie" select="'date'" />
				</xsl:call-template>
			</ns:DtFinRap>
			<ns:TxChge>
				<xsl:value-of select="format-number(row[@id='filtre1401']/col[@id=11] div 100000, '#.#####')"/>
			</ns:TxChge>
		</ns:CollCompartRapO11>
	</xsl:template>


	<xsl:template name="CONTEXT-INSTRCOMPART">
		<ns:InstrCompart>
			<ns:LibAbrInstr>
				<xsl:variable name="libInstrCompart"
					select="ext:obtenirContextForm(row[@id='filtre1401']/ficOri, row[@id='filtre1401']/ligneOri,'COMPART', row[@id='filtre1401']/col[@id=4], row[@id='filtre1401']/col[@id=5],row[@id='filtre1401']/col[@id=6],row[@id='filtre1401']/col[@id=7], $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:call-template name="replace-string">
				  <xsl:with-param name="str"
						select="$libInstrCompart" />
					<xsl:with-param name="strToReplace"
						select="'&#128;'" /><!-- On remplace le caractere euro par un encoding euro correct pour l'afficher correctement dans les pdf'-->
					<xsl:with-param name="newStr"
						select="'&#8364;'" />
				</xsl:call-template>
			</ns:LibAbrInstr>
		</ns:InstrCompart>
	</xsl:template>

	<xsl:template name="CONTEXT-DEV">
		<ns:Dev>
			<ns:CdDevIso>
				<xsl:value-of
					select="row[@id='filtre1401']/col[@id=10]" />
			</ns:CdDevIso>
		</ns:Dev>
	</xsl:template>

	<xsl:template name="CONTEXT-INSTRFONDS">
		<ns:InstrFonds>
			<ns:LibAbrInstr>
				<xsl:variable name="libInstrFonds"
					select="ext:obtenirContextForm(row[@id='filtre1401']/ficOri, row[@id='filtre1401']/ligneOri,'FONDS', row[@id='filtre1401']/col[@id=4], row[@id='filtre1401']/col[@id=5],row[@id='filtre1401']/col[@id=6], row[@id='filtre1401']/col[@id=7], $spaceParam)"
					xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
				<xsl:call-template name="replace-string">
				  <xsl:with-param name="str"
						select="$libInstrFonds" />
					<xsl:with-param name="strToReplace"
						select="'&#128;'" /><!-- On remplace le caractere euro par un encoding euro correct pour l'afficher correctement dans les pdf'-->
					<xsl:with-param name="newStr"
						select="'&#8364;'" />
				</xsl:call-template>
			</ns:LibAbrInstr>
		</ns:InstrFonds>
	</xsl:template>



	<xsl:template name="SEGMENT-ACTIF">
		<ns:Actif>
			<xsl:call-template name="ACTIF-COLLCOMPARTRAPO11110" />
			<xsl:call-template name="ACTIF-SEQS120" />
			<xsl:call-template name="ACTIF-SEQS130" />
		</ns:Actif>
	</xsl:template>

	<xsl:template name="ACTIF-COLLCOMPARTRAPO11110">
		<ns:CollCompartRapO11110>
			<ns:ActifNetGlob110>
				<xsl:value-of
					select="row[@id='filtre1401']/col[@id=12]" />
			</ns:ActifNetGlob110>
		</ns:CollCompartRapO11110>
	</xsl:template>

	<xsl:template name="ACTIF-SEQS120">
		<xsl:for-each select="row">
			<xsl:choose>
				<xsl:when test="@id='filtre1402' or @id='filtre1403'">
					<ns:S120>
						<ns:CdCssfCategPart>
							<xsl:value-of select="col[@id=6]" />
						</ns:CdCssfCategPart>
						<ns:CdAacCategPart>
							<xsl:value-of select="col[@id=9]" />
						</ns:CdAacCategPart>
						<ns:Instr>
							<ns:LibAbrInstr>
								<xsl:variable name="dtDebRap" select="ext:obtenirDate(col[@id=10])" />
                				<xsl:variable name="resultLibInstr"
									select="ext:recupLibInstr(ficOri, ligneOri, col[@id=6], col[@id=4], col[@id=5], $dtDebRap, col[@id=11], $spaceParam)"
									xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
								<xsl:value-of select="$resultLibInstr" />
							</ns:LibAbrInstr>
						</ns:Instr>
						<ns:CollCategPartRapO11120>
							<ns:ActifNetPart120>
							<xsl:value-of select="format-number(col[@id=12] div 10000, '#.####')"/>
							</ns:ActifNetPart120>
						</ns:CollCategPartRapO11120>
					</ns:S120>
				</xsl:when>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="ACTIF-SEQS130">
		<xsl:for-each select="row">
			<xsl:choose>
				<xsl:when test="@id='filtre1402' or @id='filtre1403'">
					<ns:S130>
						<ns:CdCssfCategPart>
							<xsl:value-of select="col[@id=6]" />
						</ns:CdCssfCategPart>
						<ns:CdAacCategPart>
							<xsl:value-of select="col[@id=9]" />
						</ns:CdAacCategPart>
						<ns:Instr>
							<ns:LibAbrInstr>
								<xsl:variable name="dtDebRap" select="ext:obtenirDate(col[@id=10])" />
                				<xsl:variable name="resultLibInstr"
									select="ext:recupLibInstr(ficOri, ligneOri, col[@id=6], col[@id=4], col[@id=5], $dtDebRap, col[@id=11], $spaceParam)"
									xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
								<xsl:value-of select="$resultLibInstr" />
							</ns:LibAbrInstr>
						</ns:Instr>
						<ns:TypePartRapMensO11130>
							<ns:VarPart130>
								<xsl:value-of select="format-number(col[@id=13] div 10000, '#.####')"/>
							</ns:VarPart130>
						</ns:TypePartRapMensO11130>
					</ns:S130>
				</xsl:when>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>


	<xsl:template name="SEGMENT-PORTF">
		<ns:Portf>
			<ns:RapMensO11200>
				<ns:ValPortf200>
					<xsl:value-of select="format-number(row[@id='filtre1401']/col[@id=13] div 10000, '#.####')"/>
				</ns:ValPortf200>
			</ns:RapMensO11200>
		</ns:Portf>
	</xsl:template>

	<xsl:template name="SEGMENT-MT">
		<ns:Mt>
			<xsl:call-template name="MT-RAPMENSO11310" />
			<xsl:call-template name="MT-RAPMENSO11320" />
			<xsl:call-template name="MT-RAPMENSO11330" />
		</ns:Mt>
	</xsl:template>

	<xsl:template name="MT-RAPMENSO11310">
		<ns:RapMensO11310>
			<ns:ProdNetEmis310>
				<xsl:value-of
					select="row[@id='filtre1401']/col[@id=14]" />
			</ns:ProdNetEmis310>
		</ns:RapMensO11310>
	</xsl:template>

	<xsl:template name="MT-RAPMENSO11320">
		<ns:RapMensO11320>
			<ns:Vmt320>
				<xsl:value-of
					select="row[@id='filtre1401']/col[@id=15]" />
			</ns:Vmt320>
		</ns:RapMensO11320>
	</xsl:template>

	<xsl:template name="MT-RAPMENSO11330">
		<ns:RapMensO11330>
			<ns:EmisNet330>
				<xsl:value-of
					select="row[@id='filtre1401']/col[@id=16]" />
			</ns:EmisNet330>
		</ns:RapMensO11330>
	</xsl:template>

	<xsl:template name="SEGMENT-REV">
		<ns:Rev>
			<xsl:call-template name="COLLCOMPARTRAPO11410" />
			<xsl:call-template name="REV-RAPMENSO11420" />
			<xsl:call-template name="REV-RAPMENSO11430" />
			<xsl:call-template name="REV-RAPMENSO11440" />
		</ns:Rev>
	</xsl:template>

	<xsl:template name="COLLCOMPARTRAPO11410">
		<ns:CollCompartRapO11410>
			<ns:Divid410>
				<xsl:value-of
					select="row[@id='filtre1401']/col[@id=17]" />
			</ns:Divid410>
		</ns:CollCompartRapO11410>
	</xsl:template>

	<xsl:template name="REV-RAPMENSO11420">
		<ns:RapMensO11420>
			<ns:IntObl420>
				<xsl:value-of
					select="row[@id='filtre1401']/col[@id=18]" />
			</ns:IntObl420>
		</ns:RapMensO11420>
	</xsl:template>

	<xsl:template name="REV-RAPMENSO11430">
		<ns:RapMensO11430>
			<ns:IntBanc430>
				<xsl:value-of
					select="row[@id='filtre1401']/col[@id=19]" />
			</ns:IntBanc430>
		</ns:RapMensO11430>
	</xsl:template>

	<xsl:template name="REV-RAPMENSO11440">
		<ns:RapMensO11440>
			<ns:Autre440>
				<xsl:value-of
					select="row[@id='filtre1401']/col[@id=20]" />
			</ns:Autre440>
		</ns:RapMensO11440>
	</xsl:template>

	<xsl:template name="SEGMENT-DISTRIB">
		<ns:Distrib>
			<xsl:call-template name="DISTRIB-SEQS510" />
			<xsl:call-template name="DISTRIB-SEQS520" />
		</ns:Distrib>
	</xsl:template>

	<xsl:template name="DISTRIB-SEQS510">
		<xsl:for-each select="row">
			<xsl:choose>
				<xsl:when test="@id='filtre1402' or @id='filtre1403'">
					<ns:S510>
						<ns:CdCssfCategPart>
							<xsl:value-of select="col[@id=6]" />
						</ns:CdCssfCategPart>
						<ns:CdAacCategPart>
							<xsl:value-of select="col[@id=9]" />
						</ns:CdAacCategPart>
						<ns:Instr>
							<ns:LibAbrInstr>
								<xsl:variable name="dtDebRap" select="ext:obtenirDate(col[@id=10])" />
                				<xsl:variable name="resultLibInstr"
									select="ext:recupLibInstr(ficOri, ligneOri, col[@id=6], col[@id=4], col[@id=5], $dtDebRap, col[@id=11], $spaceParam)"
									xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
								<xsl:value-of select="$resultLibInstr" />
							</ns:LibAbrInstr>
						</ns:Instr>
						<ns:CollCategPartRapO11510>
							<ns:MtGlobDistrib510>
 								<xsl:value-of select="format-number(col[@id=14] div 10000, '#.####')" />
							</ns:MtGlobDistrib510>
						</ns:CollCategPartRapO11510>
					</ns:S510>
				</xsl:when>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="DISTRIB-SEQS520">
		<xsl:for-each select="row">
			<xsl:choose>
				<xsl:when test="@id='filtre1402' or @id='filtre1403'">
					<ns:S520>
						<ns:CdCssfCategPart>
							<xsl:value-of select="col[@id=6]" />
						</ns:CdCssfCategPart>
						<ns:CdAacCategPart>
							<xsl:value-of select="col[@id=9]" />
						</ns:CdAacCategPart>
						<ns:Instr>
							<ns:LibAbrInstr>
								<xsl:variable name="dtDebRap" select="ext:obtenirDate(col[@id=10])" />
                				<xsl:variable name="resultLibInstr"
									select="ext:recupLibInstr(ficOri, ligneOri, col[@id=6], col[@id=4], col[@id=5], $dtDebRap, col[@id=11], $spaceParam)"
									xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
								<xsl:value-of select="$resultLibInstr" />
							</ns:LibAbrInstr>
						</ns:Instr>
						<ns:CollCategPartRapO11520>
							<ns:MtDistribPart520>
								<xsl:value-of select="format-number(col[@id=15] div 10000, '#.####')" />
							</ns:MtDistribPart520>
						</ns:CollCategPartRapO11520>
					</ns:S520>
				</xsl:when>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
</xsl:stylesheet>
